navigation: A11Y: https://www.a11yproject.com/ ARIA: https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA QUESTIONS: LITERATURE IS ACTIONABLE? YES! PLATFORM SHORTCUTS: ~EVERY: [TAB] [TAB] + [SHIFT] LINUX UBUNTU: WINDOWS: NARRATOR: MAC: VERNACULAR: REGION: TABINDEX: { MOLECULES, HEXAGON BRICKS }: ALERTS: ALERT DIALOGUES: https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/Alertdialog_Role NON-DIALOGUES: https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/Alert_Role SCREEN READER IMMEDIATELY READS ALERTS?

Your log in session will expire in 2 minutes

SCREEN READER CAN FOCUS ON ALERT HISTORY? ALERTS DISAPPEAR, BUT ARE ALL KEPT AND CAN BE STEPPED THROUGH MENUS: https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/menu_role ARIA: